==> kubernetes-model-1.0.45-sources.jar: annotations/io/fabric8/openshift/api/model/SecretBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class SecretBuildSourceBuilder extends SecretBuildSourceFluentImpl<SecretBuildSourceBuilder> implements VisitableBuilder<SecretBuildSource,SecretBuildSourceBuilder>{

     SecretBuildSourceFluent<?> fluent;
public SecretBuildSourceBuilder(){
    this(new SecretBuildSource());
}
public SecretBuildSourceBuilder( SecretBuildSourceFluent<?> fluent ){
    this(fluent, new SecretBuildSource());
}
public SecretBuildSourceBuilder( SecretBuildSourceFluent<?> fluent , SecretBuildSource instance ){
    this.fluent = fluent; fluent.withDestinationDir(instance.getDestinationDir()); fluent.withSecret(instance.getSecret()); 
}
public SecretBuildSourceBuilder( SecretBuildSource instance ){
    this.fluent = this; this.withDestinationDir(instance.getDestinationDir()); this.withSecret(instance.getSecret()); 
}

public EditableSecretBuildSource build(){
    EditableSecretBuildSource buildable = new EditableSecretBuildSource(fluent.getDestinationDir(),fluent.getSecret());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
SecretBuildSourceBuilder that = (SecretBuildSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.51-sources.jar: annotations/io/fabric8/openshift/api/model/SecretBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class SecretBuildSourceBuilder extends SecretBuildSourceFluentImpl<SecretBuildSourceBuilder> implements VisitableBuilder<SecretBuildSource,SecretBuildSourceBuilder>{

     SecretBuildSourceFluent<?> fluent;
public SecretBuildSourceBuilder(){
    this(new SecretBuildSource());
}
public SecretBuildSourceBuilder( SecretBuildSourceFluent<?> fluent ){
    this(fluent, new SecretBuildSource());
}
public SecretBuildSourceBuilder( SecretBuildSourceFluent<?> fluent , SecretBuildSource instance ){
    this.fluent = fluent; fluent.withDestinationDir(instance.getDestinationDir()); fluent.withSecret(instance.getSecret()); 
}
public SecretBuildSourceBuilder( SecretBuildSource instance ){
    this.fluent = this; this.withDestinationDir(instance.getDestinationDir()); this.withSecret(instance.getSecret()); 
}

public SecretBuildSource build(){
    SecretBuildSource buildable = new SecretBuildSource(fluent.getDestinationDir(),fluent.getSecret());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
SecretBuildSourceBuilder that = (SecretBuildSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
